@@ -31,9 +31,11 @@ from typing import Any, Dict, List, Tuple, Type, Union, Callable
 from simple_http_server.logger import get_logger
 
 name = "simple_http_server"
-version = "0.11.4"
+version = "0.11.6"
 
-DEFAULT_ENCODING = "UTF-8"
+DEFAULT_ENCODING: str = "UTF-8"
+
+SESSION_COOKIE_NAME: str = "PY_SIM_HTTP_SER_SESSION_ID"
 
 _logger = get_logger("simple_http_server.__init__")
 
@@ -500,6 +502,8 @@ def _get_class_of_method(method_defind):
     for attr in method_defind.__qualname__.split('.')[:-1]:
         if attr in vals:
             vals = vals[attr]
+            if not isinstance(vals, dict):
+                break
     if inspect.isclass(vals):
         return vals
 
